<?php
/**
 * Add new section to Customizer.
 *
 * CUSTOMIZER - Heroine SECTION (homepage)
 *
 *  @package marie
 */

/**
 * Require class.
 */
require_once __DIR__ . '/classes/class-marie-input.php';
require_once __DIR__ . '/classes/class-marie-cropped-image.php';

/**
 * Create Heroine section & define inputs for theme Customizer.
 * Important. Define sanitize for urls. Otherwise MARIE_Input class handles
 *
 * @param \WP_Customize_Manager $wp_customize Customizer Manager.
 */
function marie_heroine_input_fields( $wp_customize ) {

	$section = 'heroine';
	$wp_customize->add_section(
		$section,
		array(
			'title'       => __( 'Heroine Section', 'marie' ),
			'description' => __( 'Edit the Front Page Heroine Section.', 'marie' ),
		)
	);

	// Text Inputs.
	$input_args = array(

		// Heroine Tagline Section.
		array(
			'setting_id' => 'right_heading',
			'field_type' => 'text',
			'label'      => __( 'Title (defaults to site title)', 'marie' ),
		),
		array(
			'setting_id' => 'tagline_1',
			'field_type' => 'text',
			'label'      => __( 'Tagline (defaults to site tagline)', 'marie' ),
		),
		array(
			'setting_id' => 'cta_one_text',
			'field_type' => 'text',
			'label'      => __( 'CTA 1 Text', 'marie' ),
		),
		array(
			'setting_id' => 'cta_one_url',
			'field_type' => 'url',
			'label'      => __( 'CTA 1 url', 'marie' ),
			'sanitize'   => 'esc_url_raw',

		),
		array(
			'setting_id' => 'cta_two_text',
			'field_type' => 'text',
			'label'      => __( 'CTA 2 Text', 'marie' ),
		),
		array(
			'setting_id' => 'cta_two_url',
			'field_type' => 'url',
			'label'      => __( 'CTA 2 url', 'marie' ),
			'sanitize'   => 'esc_url_raw',

		),
		array(
			'setting_id' => 'cta_three_text',
			'field_type' => 'text',
			'label'      => __( 'CTA 3 Text', 'marie' ),
		),
		array(
			'setting_id' => 'cta_three_url',
			'field_type' => 'url',
			'label'      => __( 'CTA 3 url', 'marie' ),
			'sanitize'   => 'esc_url_raw',

		),
	);

	$checkbox_args = array(
		array(
			'setting_id' => 'show_section',
			'field_type' => 'checkbox',
			'label'      => __( 'Show Section', 'marie' ),
			'default'    => false,
		),
		array(
			'setting_id' => 'use_alt_heroine',
			'field_type' => 'checkbox',
			'label'      => __( 'Use alternative heroine section', 'marie' ),
			'default'    => false,
		),
	);

	// Image Inputs.
	$img_args = array(

		array(
			'setting_id' => 'blob_image',
			'label'      => __( 'Heroine Image', 'marie' ),
			'width'      => 900,
			'height'     => 500,
		),

	);

	$heroine_color_picker_args = array(
		array(
			'setting_id'  => 'marie_heroine_background_color',
			'description' => __( 'Set the Heroine section background color.', 'marie' ),
			'label'       => __( 'Background Color', 'marie' ),
			'default'     => '#04d89d',
		),
		array(
			'setting_id'  => 'marie_heroine_text_color',
			'description' => __( 'Set the Heroine section text color.', 'marie' ),
			'label'       => __( 'Text Color', 'marie' ),
			'default'     => '#444242',
		),
	);

	$heroine_stripes_color_picker_args = array(
		array(
			'setting_id'  => 'marie_heroine_stripes_1',
			'description' => __( 'Set the top stripe color.', 'marie' ),
			'label'       => __( 'Stripe 1 color', 'marie' ),
			'default'     => '#fdc800',
		),
		array(
			'setting_id'  => 'marie_heroine_stripes_2',
			'description' => __( 'Set the middle stripe color.', 'marie' ),
			'label'       => __( 'Stripe 2 color', 'marie' ),
			'default'     => '#c21f63',
		),
		array(
			'setting_id'  => 'marie_heroine_stripes_3',
			'description' => __( 'Set the bottom stripe color.', 'marie' ),
			'label'       => __( 'Stripe 3 color', 'marie' ),
			'default'     => '#ffffff',
		),
	);

	foreach ( $checkbox_args as $args ) {
		$input = new MARIE_Input( $section, $args );
		$input->register( $wp_customize );

	}
	foreach ( $heroine_color_picker_args as $args ) {
		$input = new MARIE_Color_Picker( $section, $args );
		$input->register( $wp_customize );
	}

	$input = new MARIE_Input(
		'heroine',
		array(
			'setting_id' => 'show_stripes',
			'field_type' => 'checkbox',
			'label'      => __( 'Show Stripes', 'marie' ),
		)
	);
	$input->register( $wp_customize );

	foreach ( $heroine_stripes_color_picker_args as $args ) {
		$input = new MARIE_Color_Picker( $section, $args );
		$input->register( $wp_customize );
	}

	foreach ( $img_args as $args ) {
		$img_input = new MARIE_Cropped_Image( $section, $args );
		$img_input->register( $wp_customize );

	}
	foreach ( $input_args as $args ) {
		$input = new MARIE_Input( $section, $args );
		$input->register( $wp_customize );

	}

}
add_action( 'customize_register', 'marie_heroine_input_fields' );
