<?php
/**
 * Enqueue stuff.
 *
 * @package marie
 */

/**
 * Load Front end scripts ( Theme has no admin scripts or styles ).
 */
function marie_load_scripts() {

	wp_enqueue_style( 'marie-theme-css', get_template_directory_uri() . '/dist/css/app.css', array(), '1.0.0', 'all' );

	wp_enqueue_script( 'marie-main-js', get_template_directory_uri() . '/dist/js/app.js', null, '1.0.0', true );

	if ( is_front_page() ) {
		wp_enqueue_script( 'marie-front-js', get_template_directory_uri() . '/dist/js/front.js', null, '1.0.0', true );
	}

	// Google Fonts - used for headings.
	wp_enqueue_style( 'marie-montserrat-font', 'https://fonts.googleapis.com/css2?family=Montserrat:wght@300;400;500;600;700;800;900&display=swap', array(), '1.0' );

	// Also add 'torn' styles ( marie-page-header & marie-frontpage-sections ).
	marie_torn_styles();
}
add_action( 'wp_enqueue_scripts', 'marie_load_scripts' );


/**
 * Adds the torn styles inline.
 */
function marie_torn_styles() {

	// Manually call header ( pseudo element is different ).
	$header_css = marie_get_torn_css( '#ffffff', 'header#marie-page-header', 'after' );
	wp_add_inline_style( 'marie-theme-css', $header_css );

	// List of frontpage sections with 'torn' available in theme customiser.
	$sections = array( 'about', 'features', 'widget-section-one', 'widget-section-two', 'widget-section-three' );

	// Loop $sections, get the css string and add as 'inline style'.
	foreach ( $sections as $section ) {
		$torn = get_theme_mod( $section . '_torn_section' );
		if ( $torn ) {
			$bg_color = get_theme_mod( $section . '_background_color' );
			$selector = 'section#marie-frontpage-' . $section;
			$pseudo   = 'before';
			if ( $bg_color && $selector && $pseudo ) {

				$custom_css = marie_get_torn_css( $bg_color, $selector, $pseudo );
				wp_add_inline_style( 'marie-theme-css', $custom_css );
			}
		}
	}
}

/**
 * Gets css to show torn sections. Give svg background the same $bg-color. Placement (before or after) depends on pseudo.
 *
 * Note: This function originally encoded svg using base64_encode() but this is not allowed in WordPress. The SVG is now manually encoded with JavaScripts encodeURIComponent(). Note $ok_bg_color replaces hash in the user defined background color so it works with utf8.
 *
 * @param string $bg_color The color to use for the svg background.
 * @param string $selector The css selector eg '#marie-frontpage-widget-section-one'.
 * @param string $pseudo The pseudo element to use eg.'::before'.
 */
function marie_get_torn_css( $bg_color, $selector, $pseudo ) {

	// Get the 'percentage encoding' friendly version of hex value.
	$ok_bg_color = str_replace( '#', '%23', $bg_color );
	ob_start();
	?>

		<?php
		echo esc_attr( $selector ) . '::' . esc_attr( $pseudo ) . '{';
			echo 'position: absolute;';
			echo 'left: -25vw;';
			echo 'width: 150vw;';
			echo 'before' === $pseudo ? 'top: -5rem;' : 'bottom: -1rem;';
			echo 'left: -25vw;';
			echo 'height: 8rem;';
			echo "content: '';";
			echo "background-image: url('data:image/svg+xml;utf8,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20version%3D%221.1%22%20width%3D%221488.7%22%20%20viewBox%3D%220%200%20394%2038%22%20preserveAspectRatio%3D%22none%22%3E%3Cpath%20d%3D%22M394%2013v25H0V15c12%200%2023-4%2034-7%2010-2%2020%200%2030-2l28-3c11-4%2022-3%2032-2%2011-1%2021%201%2032%201%2010%202%2020%207%2032%205%209%200%2018%204%2027%201l27-3c12%200%2024%200%2036-2s23%203%2034%201c11%200%2021%204%2032%205%2010%200%2021%208%2032%202l18%202z%22%20fill%3D%22" . esc_attr( $ok_bg_color ) . "%22%2F%3E%3C%2Fsvg%3E');";
			echo 'background-size: cover;';
			echo 'background-position: center top;';
			echo '	background-repeat: no-repeat;';
			echo '	}';
		?>

	<?php
	$txt = ob_get_clean();
	if ( $txt ) {
		return $txt;
	}
	return false;
}
