<?php
/**
 * Custom template tags for marie.
 *
 * @package marie
 */

/**
 * Render preview of next/previous post (see post-preview-navigation.php).
 * This is roughly the same as content-post.
 * maybe should use setup_post_data() and get the template part but that involves setting this $marie_post to the global post which seems wrong but maybe is okay? (https://developer.wordpress.org/reference/functions/setup_postdata/#more-information)  Going with this, not DRY but not wrong.
 *
 * @param WP_POST $marie_post post.
 * @param string  $text eg. 'Next Post'.
 * @return string $output. html to show post preview.
 */
function marie_post_nav_preview( $marie_post, $text ) {
	if ( ! $marie_post || '' === $marie_post ) {
		return '<span></span>';
	}

	$marie_post_title     = $marie_post->post_title;
	$marie_post_id        = $marie_post->ID;
	$marie_post_permalink = get_the_permalink( $marie_post_id );
	ob_start();
	?>
		<div class="marie-post-nav-post-wrap">
			<a class="" href="<?php echo esc_url( get_permalink( $marie_post->ID ) ); ?>">
				<?php echo esc_html( $text ); ?>
			</a>

			<article  id="post-<?php echo esc_attr( $marie_post_id ); ?>" <?php post_class( 'marie-non-single marie-card' ); ?>>

				<?php

				if ( has_post_thumbnail( $marie_post_id ) ) {
					?>
					<div class="entry-header">
						<figure class="post-thumbnail">
							<a href="<?php echo esc_url( get_permalink( $marie_post->ID ) ); ?>" aria-hidden="true" tabindex="-1">
								<?php echo get_the_post_thumbnail( $marie_post_id, 'medium' ); ?>
							</a>
						</figure>
					<?php
				} else {
					?>
						<div class="entry-header entry-header-empty">
							<?php
							// Empty span so the grid don't break.
							echo '<span></span>';
				}
				?>
						<span class="entry-meta-date">
							<?php echo wp_kses_post( get_the_time( 'F jS, Y', $marie_post_id ) ); ?>
						</span>
					</div><!-- .entry-header (or .entyr-header.entry-header-empty) -->

					<div class="entry-content">
						<h3 class="heading-size-3"><?php echo wp_kses( $marie_post_title, array() ); ?></h3>
						<p><?php echo wp_kses_post( get_the_excerpt( $marie_post_id ) ); ?></p>
					</div>

					<footer class="entry-footer">
						<a 
							href="<?php echo esc_url( $marie_post_permalink ); ?>" 
							class="marie-default-btn"
						>
							<span class="screen-reader-text">
								<?php esc_html_e( 'Read More about', 'marie' ); ?>
								<?php echo esc_html( $marie_post_title ); ?>
							</span>
							<span><?php esc_html_e( 'More', 'marie' ); ?></span>
						</a>
					</footer>
			</article>
		</div>
	<?php
		$output = ob_get_clean();

	if ( $output ) {
		return $output;
	}
}

/**
 * Render <a> Logo </a>.
 *
 * @param string $link The url to wrap the logo in.
 * @param string $logo The logo.
 *
 * @return string $output. Either the site logo wrapped in <a> tags or empty <span> tags.
 */
function marie_render_linked_logo( $link, $logo ) {

	// If there's no link arg, use the site url.
	if ( ! $link || '' === $link ) {
		$link = esc_url( home_url( '/' ) );
	}

	// If there's no logo arg, use the custom site logo.
	if ( '' === $logo || ! $logo ) {
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		$logo_dets      = wp_get_attachment_image_src( $custom_logo_id, 'full' );
		if ( $logo_dets && is_array( $logo_dets ) ) {
			$logo = $logo_dets[0];
		}

		if ( ! $custom_logo_id || ! $logo ) {
			// Quick fix so that header grid columns don't fall apart without a logo.
			return '<span></span>';
		}
	}

	ob_start();
	?>
		<a 
		href="<?php echo esc_url( $link ); ?>" 
		class="custom-logo-link <?php echo is_front_page() ? 'marie-frontpage-logo' : null; ?>" 
		rel="home">
		<?php
		if ( has_custom_logo() ) :
			echo '<img src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . ' logo">';
		else :
			echo '<p class="base-font-size">' . esc_html( get_bloginfo( 'name' ) ) . '</p>';
		endif;
		?>
	</a>
	<?php

	$txt_logo = ob_get_clean();
	if ( $txt_logo ) {
		return $txt_logo;
	}
}

/**
 * Render appropiate header title on top of pages.
 *
 * @param string $manual_title So the page title can be set from templates.
 */
function marie_render_page_header( $manual_title = false ) {

	// If page title has been passed from template, use that.
	if ( ! empty( $manual_title ) && is_string( $manual_title ) ) {
		set_query_var( 'use_title', $manual_title );
	} else {
		$page_header_title = marie_get_page_header_title();
		if ( ! empty( $page_header_title ) && is_string( $page_header_title ) ) {
			set_query_var( 'use_title', $page_header_title );
		}
	}

	// If neither var set, something is wrong so leave the page title empty?.
	if ( ! $manual_title && ! $page_header_title ) {
		set_query_var( 'use_title', '' );
	}

	// Finally always show the page header.
	get_template_part( 'template-parts/content/header/content-page-header' );
}

/**
 * Render pagination
 */
function marie_maybe_render_pagination() {
	// paginate_links() returns string || array. void if not enough pages.
	$marie_pagination = wp_kses_post( paginate_links() );
	$output           = '';
	if ( is_array( $marie_pagination ) || ( is_string( $marie_pagination ) && '' !== $marie_pagination ) ) {
		$output  = '<div class="marie-pagination">';
		$output .= wp_kses_post( $marie_pagination );
		$output .= '</div>';
		echo wp_kses_post( $output );
	}
}
