/* eslint-disable no-shadow */
/* eslint-disable computed-property-spacing */

/**
 * Accessibilty-wise the main menu was originally based on WordPress Twenty Twenty-One Theme, using display: none to hide non-active sub menus.  Wp accessibility handbook requirements (https://make.wordpress.org/themes/handbook/review/accessibility/required/#keyboard-navigation) say not to use display:none - "Fails: Dropdown navigation menus are hidden using display:none; and brought into view on :hover" Do they mean DON'T use display none on dropdowns or don't use display none on dropdowns if you're only using hover to bring them into focus?? Anyway, to be on the safe side I have changed scss to NOT use display:none. Consequenly we now need to remove invisible links & toggle buttons from the tab order and add/remove them as required during tabbing & opening/closing sub menus.
 *
 **/

import mobileMenuToggle from './navigation/mobile-menu-toggle';
import subMenuToggle from './navigation/sub-menu-toggle';
import categorySelect from './category-select';
import giganticMenu from './gigantic-menu';
import mouseNavigation from './navigation/mouse-navigation';
import menuStates from './navigation/menu-states';
import menuKeyboardNavigation from './navigation/mobile-keyboard';

/*===============================================================
Navigation
===============================================================*/

// Add gigantic-menu class when menu runs out of horizontal space. It's important that this happens BEFORE subMenuToggle because the tab order will be affected based on whether the marie-gigantic-class is present or not.
giganticMenu();

// Toggle sub menus.
subMenuToggle();

// Toggle sub menus with mouseenter/mouseleave. ( handler returns if util.isMobile() === true).
mouseNavigation();

// Open & close mobile menu.
mobileMenuToggle();

// Handle mobile keyboard events. Esc to close etc. Trap focus. (returns if !util.isMobile())
menuKeyboardNavigation();

// Observer on header. Handles tab index & add/remove click anywhere to close function.
menuStates();

/*===============================================================
Blog Page.
===============================================================*/

// ALWAYS (BLOG PAGE). Select category from dropdown on mobile.
categorySelect();

/*===============================================================
Header - Add .with-bg-color on scroll.
===============================================================*/
document.addEventListener( 'scroll', handleHeaderBgColor );

const header = document.getElementById( 'marie-main-header' );

// const headerHeight = document.getElementsByTagName( 'header' )[0].offsetHeight;

// Add the sticky class to the header when you reach its scroll position. Remove "sticky" when you leave the scroll position
function handleHeaderBgColor() {
	if ( ! header ) {
		return;
	}
	const headerHeight = header.offsetHeight;
	if ( window.pageYOffset > headerHeight ) {
		header.classList.add( 'with-bg-color' );
	} else {
		header.classList.remove( 'with-bg-color' );
	}
}

/*===============================================================
Intersecion observer - fade in paragraphs
===============================================================*/
const paras = document.getElementsByTagName( 'p' );

const observer = new IntersectionObserver( ( paras ) => {
	paras.forEach( ( para ) => {
		if (
			para.intersectionRatio > 0 &&
			! para.target.classList.contains( 'animated' )
		) {
			para.target.style.animation = `fadeInText 1000ms ease-out 0ms 1`;
			para.target.classList.add( 'animated' );
		} else {
			para.target.style.animation = 'none';
		}
	} );
} );

Array.from( paras ).forEach( ( para ) => {
	observer.observe( para );
} );
