/* eslint-disable no-shadow */
/* eslint-disable no-mixed-operators */

/**
 * If is front page...
 *
 * 1. Listen to menu items with #anchor links to home page (.menu-item-type-custom)
 * 2. Also listen to a.marie-maybe-custom-link (Class will be on any custom links added via theme customiser)
 * 3. Get hashes on click
 * 4. get element with hashes' corresponding #id
 * 5. scroll there with header offset accounted for.
 */
function scrollTo() {
	// eslint-disable-next-line indent
	// Get menu items with a custom link.
	const menuItems = document.querySelectorAll( '.menu-item-type-custom' );

	if ( menuItems && menuItems.length ) {
		menuItems.forEach( ( menuItem ) => {
			// Add listener only if menuItem > a has a hash.
			if (
				menuItem.firstElementChild.tagName === 'A' &&
				menuItem.firstElementChild.hash
			) {
				menuItem.addEventListener( 'click', handleScrollTo );
			}
		} );
	}

	// Get custom links added via theme customiser.
	const themeCustomiserLinks = document.querySelectorAll(
		'.marie-maybe-custom-link'
	);

	if ( themeCustomiserLinks && themeCustomiserLinks.length ) {
		themeCustomiserLinks.forEach( ( linkItem ) => {
			// Add listener only if linkItem has a hash.
			if ( linkItem.hash ) {
				linkItem.addEventListener( 'click', handleScrollTo );
			}
		} );
	}

	function handleScrollTo( e ) {
		e.stopPropagation();
		const DURATION = 300;
		let startTime = null;

		// Get the id of the element we want to scroll to.
		const targetElementId = getTargetElementIdFromHash( e );
		if ( ! targetElementId ) {
			return;
		}

		// Get the element we want to scroll to.
		const targetEl = document.querySelector( `${ targetElementId }` );
		if ( ! targetEl ) {
			return;
		}

		// Get height of site header.
		const header = document.querySelector( 'header#marie-main-header' );
		if ( ! header ) {
			return;
		}
		const headerHeight = header.offsetHeight;

		// Get position of element we want to scroll to.
		const targetPosition =
			targetEl.getBoundingClientRect().top + window.scrollY; // Note scrollY

		// Get current position.
		const startPosition = window.pageYOffset;

		// Get distance between them.
		const distance = targetPosition - startPosition - headerHeight;

		function animation( currentTime ) {
			if ( startTime === null ) {
				startTime = currentTime;
			}
			const timeElapsed = currentTime - startTime;
			const run = easy( timeElapsed, startPosition, distance, DURATION );

			window.scrollTo( 0, run );
			if ( timeElapsed < DURATION ) {
				requestAnimationFrame( animation );
			}
		}

		// util function
		function getTargetElementIdFromHash( e ) {
			if ( e.target.tagName === 'A' ) {
				return e.target.hash;
			} else if ( e.currentTarget.tagName === 'A' ) {
				return e.currentTarget.hash;
			}
			return null;
		}

		// util function (taken from http://www.gizma.com/easing/)
		function easy( t, b, c, d ) {
			t /= d / 2;
			if ( t < 1 ) {
				return ( c / 2 ) * t * t * t * t + b;
			}
			t -= 2;

			return ( -c / 2 ) * ( t * t * t * t - 2 ) + b;
		}

		requestAnimationFrame( animation );
	}
}
scrollTo();
