/* eslint-disable space-unary-ops */
/**
 * Because Header is fixed @ 7rem/5rem in height, all menu items need to fit on one line. In case there are too many items in the menu use the mobile burger menu instead.
 *
 * If the page loads wide enough to show the full menu this will show burger button if the page shrinks.
 * If the page loads too narrow to show the full menu this WILL NOT show the full menu if the page width increases.
 *
 */
const giganticMenu = () => {
	/**
	 * If nav width is greater than ~screen width add the class '.marie-gigantic-menu' to the site header. CSS will handle the rest.
	 */
	function maybeUseMobileMenu() {
		const navMenu = document.querySelector( 'ul#marie-main-menu' );
		if ( !navMenu ) {
			return;
		}

		const header = document.querySelector( 'header#marie-main-header' );
		if ( !header ) {
			return;
		}

		const navMenuDets = navMenu.getBoundingClientRect(); // includes padding and border-width
		if ( !navMenuDets.width ) {
			return;
		}

		const windowWidth = document.documentElement.clientWidth; // ~like css vws
		if ( !windowWidth ) {
			return;
		}

		/*
    // Approx space on the left = 5vw.
    const marginLeft = 5 * (windowWidth / 100);

    // Approx Space on the right = 6rem;
    const marginRight = 6 * 16;
    */

		// Add class if menu is wider than approx available width.
		// Approx available width is 100vw - ( (10vw + 7.5rem )* 2), using 100vw - 40vw.
		const marginLeft = 20 * ( windowWidth / 100 ); // 20vw
		const marginRight = 20 * ( windowWidth / 100 ); //  20vw
		const buffer = 112;
		const approxNavSpace = windowWidth - marginRight - marginLeft - buffer;

		// If the nav menu does not fit in the available space, use the .marie-gigantic-menu class.
		if ( navMenuDets.width > approxNavSpace ) {
			if ( ! header.classList.contains( 'marie-gigantic-menu' ) ) {
				header.classList.add( 'marie-gigantic-menu' );
				return;
			}
		}

		// If the nav menu width is less than the available space, check if we should remove the .gigantic class or not. It's tricky to measure the full width nav in this case because it may be in burger menu form. Remove the .gigantic class (but set opacity=0) while we measure it. If it will fit restore the opacity. If it will not fit restore the opacity AND the .gitantic class.
		if ( navMenuDets.width < approxNavSpace ) {
			if ( header.classList.contains( 'marie-gigantic-menu' ) ) {
				// Show (with opacity: 0) and measure the full width nav.
				header.classList.remove( 'marie-gigantic-menu' );
				navMenu.style.opacity = 0;
				const updatedNavMenuDets = navMenu.getBoundingClientRect();

				// 1. If nav still doesn't fit, restore the .marie-gigantic-menu-class.
				if ( updatedNavMenuDets.width > approxNavSpace ) {
					header.classList.add( 'marie-gigantic-menu' );
				}

				// always restore the opacity.
				navMenu.style.opacity = 1;
			}
		}
	}

	/**
	 * Run the resize handler through this so it only fires according to the wait param.
	 *
	 * @param {Function} func function Function to debounce.
	 * @param {string} wait time.
	 */
	function debounce( func, wait ) {
		let timeout;
		return function() {
			const context = this;
			const args = arguments;
			const later = function() {
				timeout = null;
				func.apply( context, args );
			};
			clearTimeout( timeout );
			timeout = setTimeout( later, wait );
		};
	}

	// 1. Always run function once.
	maybeUseMobileMenu();

	//  2. Add listener so function runs on resize.
	window.addEventListener( 'resize', debounce( maybeUseMobileMenu, 150 ) );
};

export default giganticMenu;
