/* eslint-disable computed-property-spacing */
/* eslint-disable array-bracket-spacing */
import { navigationUtil } from '../util';
const {
	removeNavSubItemsFromTabOrder,
	removeAllNavItemsFromTabOrder,
	isMobile,
	addAllToTabOrder,
	getMenuState,
} = navigationUtil;

import { navigationHandlers } from '../handlers';
const { handleClickAnywhereToClose } = navigationHandlers;

function menuStates() {
	// 	Observe classList changes on the header.
	const mobileToBigObserver = new MutationObserver( ( mutations ) => {
		mutations.forEach( ( mutation ) => {
			// Check if attributes ( we are only observing 'class') changed.
			if (
				mutation.type === 'attributes' &&
				mutation.oldValue !== mutation.target.classList.value
			) {
				// getMenuState() returns one of:
				// 1. 'MOBILE_CLOSED' = Mobile Screen | Menu Closed.
				// 2. 'MOBILE_OPEN' 	= Mobile Screen | Menu Open.
				// 3. 'BIG_SCREEN' 	  = Big Screen ( Menu always Open ).
				// 4. false.					= Something is wrong.
				const menuState = getMenuState();

				if ( menuState === 'MOBILE_CLOSED' ) {
					// 1. Menu is hidden, make all items UNtabbable.
					removeAllNavItemsFromTabOrder();

					// 2. Remove the click anywhere to close listener.
					const main = document.getElementsByTagName( 'main' );
					if ( main && main.length ) {
						main[0].removeEventListener( 'click', handleClickAnywhereToClose );
					}
				} else if ( menuState === 'MOBILE_OPEN' || menuState === 'BIG_SCREEN' ) {
					// 1. Make top level menu items tabbable (sub-menu-toggle handles the rest).
					removeNavSubItemsFromTabOrder();

					// 2. Add the click anywhere to close listener.
					const main = document.getElementsByTagName( 'main' );
					if ( main && main.length ) {
						main[0].addEventListener( 'click', handleClickAnywhereToClose );
					}
				} else {
					// If getMenuState() returned false, something is wrong. Restore the natural tab order.
					addAllToTabOrder();
				}
			}
		} );
	} );

	// On init tab items
	if ( isMobile() ) {
		// On load the mobile menu is closed, remove all.
		removeAllNavItemsFromTabOrder();
	} else {
		removeNavSubItemsFromTabOrder();
	}

	const theHeader = document.getElementById( 'marie-main-header' );
	if ( theHeader ) {
		mobileToBigObserver.observe( theHeader, {
			attributes: true,
			attributeFilter: ['class'],
			subtree: false,
			attributeOldValue: true,
		} );
	}
}
export default menuStates;
