/**
 * Mobile Menu Only.
 * Traps tabbing between burger btn & menu items.
 * Use esc key to exit & close the menu.
 */

import { navigationUtil } from '../util';
const { toggleAriaExpanded, isMobile } = navigationUtil;

const menuKeyboardNavigation = function() {
	const header = document.getElementById( 'marie-main-header' );

	document.addEventListener( 'keydown', function( event ) {
		if ( ! isMobile() ) {
			return;
		}
		const burgerBtn = document.querySelector( '.marie-burger-btn' );
		let isExpanded = false;
		if ( burgerBtn && burgerBtn.getAttribute( 'aria-expanded' ) === 'true' ) {
			isExpanded = true;
		}
		const mainNavMenu = document.querySelector( '#marie-main-nav' );
		const selectors = 'input, a, button';

		const tabKey = event.key === 'Tab';
		const shiftKey = event.shiftKey;
		const escKey = event.key === 'Escape';

		const els = mainNavMenu.querySelectorAll( selectors );
		const elements = Array.prototype.slice.call( els );
		const activeEl = document.activeElement;
		const lastEl = elements[ elements.length - 1 ];

		// Get the last button.sub-menu-toggle without a tabindex=-1 attribute.
		function getLastRelevantToggleBtn() {
			const subBtns = mainNavMenu.querySelectorAll(
				':scope button.sub-menu-toggle:not([tabindex="-1"]'
			);
			if ( ! subBtns || ! subBtns.length ) {
				return false;
			}

			// Get non nested togglebtns & nested togglebtns in tab order.
			const activeBtns = Array.from( subBtns ).filter(
				( btn ) => btn.getAttribute( 'aria-expanded' ) === 'false'
			);
			if ( ! activeBtns || ! activeBtns.length ) {
				return false;
			}

			const lastActiveBtn = activeBtns[ activeBtns.length - 1 ];
			return lastActiveBtn;
		}

		//const firstEl = elements[0];
		const firstEl = document.querySelector( '.marie-burger-btn' );

		// Close mobile menu with escape key.
		if ( escKey && isExpanded && isMobile() ) {
			event.preventDefault();

			header.classList.remove( 'nav-open' );
			mainNavMenu.classList.remove( 'show' );
			toggleAriaExpanded( burgerBtn );
			burgerBtn.focus();
		}
		// Return after esc key if not expanded?
		if ( ! isExpanded || ! isMobile() ) {
			return;
		}

		// Keep tabbing inside the menu (last item to first item). The Element to use to send the tab back to firstEl is either lastEl OR lastRelevantToggleBtn if lastEl[tabindex=-1].
		let lastRelevantLinkOrToggleBtn = lastEl;

		if ( lastEl.getAttribute( 'tabindex' ) === '-1' ) {
			lastRelevantLinkOrToggleBtn = getLastRelevantToggleBtn();
		}

		if ( ! shiftKey && tabKey && activeEl === lastRelevantLinkOrToggleBtn ) {
			event.preventDefault();
			firstEl.focus();
		}

		// Keep tabbing inside the menu (first item to last item). The element to send focus to is either lastEl or LastRelevantToggleBtn if lastEl[tabindex=-1].
		if ( shiftKey && tabKey && firstEl === activeEl ) {
			event.preventDefault();

			// el to focus is
			let elToFocus = lastEl;
			if ( lastEl.getAttribute( 'tabindex' ) === '-1' ) {
				elToFocus = getLastRelevantToggleBtn();
			}
			elToFocus.focus();
		}

		// If there are no elements in the menu, don't move the focus
		if ( tabKey && firstEl === lastEl ) {
			event.preventDefault();
		}
	} );
};

export default menuKeyboardNavigation;
