import { navigationUtil } from '../util';

const { keepSubMenusVisible, isMobile } = navigationUtil;

/**
 * Big Screens - Show/hide sub-menus onmouseenter/leave toggle buttons.
 */
function mouseNavigation() {
	// Get ALL <li.menu-item-has-children> items with nested ul.sub-menus
	// NOTE: #marie-main-menu corresponds to the 'menu_id' arg to wp_nav_menu().
	const lisWithChildren = document.querySelectorAll(
		'#marie-main-menu .menu-item-has-children'
	);

	if ( ! lisWithChildren || ! lisWithChildren.length ) {
		return;
	}

	// Show onMouseEnter.
	lisWithChildren.forEach( ( li ) => {
		li.addEventListener( 'mouseenter', function showSubMenu() {
			// Don't do anything if mobile menu is showing.
			const mobile = isMobile();
			if ( mobile ) {
				return;
			}
			this.querySelector( '.sub-menu-toggle' ).setAttribute(
				'aria-expanded',
				'true'
			);

			// change css class if sub-menu goes off RHS of screen.
			keepSubMenusVisible( li );
		} );

		// hide onMouseLeave
		li.addEventListener( 'mouseleave', function hideSubMenu() {
			// Don't do anything if mobile menu is showing.
			const mobile = isMobile();
			if ( mobile ) {
				return;
			}
			this.querySelector( '.sub-menu-toggle' ).setAttribute(
				'aria-expanded',
				'false'
			);
		} );
	} );
}
export default mouseNavigation;
