<?php
/**
 * Displays the site header.
 *
 * @package marie
 */

// WordPress Settings.
$show_title_tagline = get_theme_mod( 'header_text' );

// Logo.
$custom_logo_id = get_theme_mod( 'custom_logo' );
$logo           = wp_get_attachment_image_src( $custom_logo_id, 'full' );


// "If a particular role appears more than once on a page, provide an ARIA label for that role" (header)
?>

<a href="#main" class="skip-link screen-reader-text" >
	<?php echo esc_html_e( 'Skip to main content', 'marie' ); ?>
</a>
<header id="marie-main-header" class="header" aria-label="<?php esc_attr_e( 'marie-primary-header', 'marie' ); ?>" >

<div class="header-left">

	<?php
	// 1. If there is a logo show it.
	if ( ! empty( $logo[0] ) ) {

		echo wp_kses_post( marie_render_linked_logo( '', $logo[0] ) );

		// 2. If there is no Logo & show header_text selected in WP customiser settings.
	} elseif ( empty( $logo[0] ) && 1 === $show_title_tagline ) {
		?>
			<a 
			href="<?php echo esc_url( home_url( '/' ) ); ?>" 
			class="custom-logo-link <?php echo is_front_page() ? 'marie-frontpage-logo' : null; ?>" 
			rel="home"
			>
				<p><?php echo esc_html( get_bloginfo( 'name' ) ); ?></p>
			</a>
		<?php
	} else {
		// Render an empty span to keep the grid together. // NOTE: marie_render_linked_logo above also returns empty span tags if something goes wrong.
		echo '<span></span>';

	}
	?>
	<button 
		class="marie-burger-btn" 
		data-toggle="collapse" 
		data-target="#marie-main-nav" 
		aria-controls="marie-main-nav" 
		aria-expanded="false" 
	>
		<span class="dropdown-icon open">
			<span class="screen-reader-text"><?php esc_html_e( 'Menu', 'marie' ); ?></span>
			<?php echo marie_get_theme_svg( 'burger_menu' ); // phpcs:ignore WordPress.Security.EscapeOutput -- svg goes through wp_kses in marie_get_theme_svg() ?>
		</span>
		<span class="dropdown-icon close">
			<span class="screen-reader-text"><?php esc_html_e( 'Close', 'marie' ); ?></span>
			<?php echo marie_get_theme_svg( 'close_menu' ); // phpcs:ignore WordPress.Security.EscapeOutput -- svg goes through wp_kses in marie_get_theme_svg() ?>
		</span>
	</button>

	<nav id="marie-main-nav" >
		<?php
		if ( has_nav_menu( 'main-menu' ) ) {

			wp_nav_menu(
				array(
					'theme_location' => 'main-menu',
					'depth'          => 0,
					'show_toggles'   => true,
					'container'      => false,
					'menu_class'     => 'navbar-nav',
					'menu_id'        => 'marie-main-menu', // This is important!! see navigation.js.
					'fallback_cb'    => false,
				)
			);
		}
		?>
	</nav>
			<?php

			if ( has_nav_menu( 'socials-header' ) ) {

				// Header socials menu could potentially cover the ctas. If there are more than four items, add extra class '.keep-menu-left' to the ul and move it to the left of the screen.

				// Get count of social menu items.
				$theme_locations   = get_nav_menu_locations();
				$menu_obj          = get_term( $theme_locations['socials-header'], 'nav_menu' );
				$num_items_in_menu = $menu_obj->count;

				wp_nav_menu(
					array(
						'theme_location'       => 'socials-header',
						'link_before'          => '<span>',
						'link_after'           => '</span>',
						'container'            => 'nav',
						'container_aria_label' => 'socials-menu-header',
						'menu_class'           => $num_items_in_menu <= 4 ? 'navbar-socials' : 'navbar-socials keep-menu-left',
						'depth'                => 1,
					)
				);
			}
			?>
</div>

</header>
