<?php
/**
 * Displays category links.
 * Used in index.php and category.php.
 *
 * Gets list of categories and shows each link and number of posts.
 * Eg, <a href"/news">News (5)</a>
 * See category-select.js.
 *
 * @package marie
 */

?>
<div class="category-links-wrap">
	<?php
	// get all categories (ignores unused categories by default).
	$kats = get_categories();

	foreach ( $kats as $kat ) {

		// get this category url.
		$kat_link = get_category_link( $kat->term_id );

		// prepare link html.
		$category_link = sprintf(
			'<a class="marie-list-link" href="%1$s" title="%2$s">%3$s</a>',
			esc_url( $kat_link ),
			/* translators: %s: category name. */
			esc_attr( sprintf( __( 'View all posts in %s', 'marie' ), $kat->name ) ),
			esc_html( $kat->name ) . '<span> (' . esc_html( $kat->category_count ) . ')</span>'
		);
		echo wp_kses_post( $category_link );
	}
	?>
</div>

<div class="category-links-wrap-mobile">

	<form id="marie-category-select-form" class="category-select" action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
	<label for="marie-category-select" class="screen-reader-text">Select Category</label>
		<?php
		$args = array(
			'show_option_none' => __( 'Select category', 'marie' ),
			'show_count'       => 1,
			'orderby'          => 'name',
			'echo'             => 0,
			'id'               => 'marie-category-select', // Important for js (also form#marie-category-select-form).
		);

		// See category-select.js.
		echo wp_dropdown_categories( $args );
		?>
	</form>

</div>
